@@ -102,7 +102,7 @@ class PytestDriver(BaseTestDriver):
   """
 
   directory: Optional[str] = None
-  args: List[str] = field(default_factory=list)
+  args: List[str] = field(default_factory=lambda: ['-vv'])
   report_file: str = field(default='.pytest-report.json')
 
   # BaseTestDriver
